
#version 400

in vec2 texCoords;
in vec3 posModel;
in vec3 normal;

in vec4 ShadowCoord;

out vec4 FragColor;

uniform sampler2D terrain;

uniform sampler2D gSampler0;
uniform sampler2D gSampler1;
uniform sampler2D gSampler2;

uniform sampler2DShadow shadowMap;


struct SimpleDirectionalLight
{
	vec3 vColor;
	vec3 position;
	float fAmbientIntensity;
};

uniform SimpleDirectionalLight sunLight;


void main()
{

 
	//1st is the highest layer
	const float layer1 = 0.75f;
	const float layer2 = 0.65f;
	const float layer3 = 0.50f;
	const float layer4 = 0.40f;


	vec4 vTexColor = vec4(0.0f);

	//Calculates the color of the current fragment
	if(posModel.y >=layer1){
		 vTexColor= texture2D(gSampler0, texCoords);
	}
	else if (posModel.y >=layer2){

		//blends the 1st and the second texture together scale variable say how much color of a certain texture is used

		float scale = posModel.y - layer2;
		scale /= (layer1-layer2);

		float scale2 = scale;
		scale = 1.0 - scale;


		vTexColor += texture2D(gSampler0, texCoords)*scale2;
		vTexColor += texture2D(gSampler1, texCoords)*scale;

	}
	else if (posModel.y >=layer3){
		vTexColor = texture2D(gSampler1, texCoords); 	
	}
	else if (posModel.y >=layer4){

		//blends the 1st and the second texture together scale variable say how much color of a certain texture is used	

		float scaleLowerTex = posModel.y - layer4;
		scaleLowerTex /= (layer3-layer4);

		float scaleHeigerTex = scaleLowerTex;
		scaleLowerTex = 1.0 - scaleLowerTex;


		vTexColor += texture2D(gSampler1, texCoords)*scaleHeigerTex;
		vTexColor += texture2D(gSampler2, texCoords)*scaleLowerTex;

	}
	else{
		vTexColor = texture2D(gSampler2, texCoords);
	}

	float visibility = textureProj(shadowMap, ShadowCoord);



		//calculates the lightning of the current fragment
	float fDiffuseIntensity = max(0.0, dot(normalize(normal), normalize(sunLight.position-posModel)));

	//float fDiffuseIntensity = max(0.0, dot(normalize(normal), normalize(sunLight.position)));

	FragColor = visibility*vTexColor*vec4(sunLight.vColor*(sunLight.fAmbientIntensity+fDiffuseIntensity), 1.0);


 }